Index: uspace/lib/c/arch/ia32/src/entry.S
===================================================================
--- uspace/lib/c/arch/ia32/src/entry.S	(revision 3fafe5e03bb501f8627b315f8e97330dd3996f86)
+++ uspace/lib/c/arch/ia32/src/entry.S	(revision e63468473345cf0a982276dc4d69b496d2a0f7ec)
@@ -65,5 +65,5 @@
 	movl %esp, %ebp
 
 	# Pass the PCB pointer to __main as the first argument
 	pushl %edi
-	call __main
+	call __libc_main
@@ -65,5 +65,5 @@
 	movl %esp, %ebp
 
-	# Pass the PCB pointer to __main as the first argument
+	# Pass the PCB pointer to __libc_main as the first argument
 	pushl %edi
